/*
 * Copyright (C) 2004 Robert Hogan <robert at roberthogan dot net>
 */

#include "klamav.h"
#include "version.h"
#include "klamavconfig.h"
#include <kaboutdata.h>
#include <kcmdlineargs.h>

static const char *description =
    I18N_NOOP("KlamAV - Virus Protection for KDE");

static const char *version = KLAMAV_VERSION;
//static const char title[] = "KlamAV";

static KCmdLineOptions options[] =
{
    { "+[URL]", I18N_NOOP( "Document to open." ), 0 },
    { "scanthis", I18N_NOOP("Scan this..."), 0 },
    { 0, 0, 0 }
};

int main(int argc, char **argv)
{
    KAboutData about("klamav", I18N_NOOP(""), version, description,
                     KAboutData::License_GPL, "(C) 2004 Robert Hogan", 0, 0, "robert at roberthogan dot net");
    about.addAuthor( "Robert Hogan", 0, "robert at roberthogan dot net" );
    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions(options);
    KApplication app;
    

    // register ourselves as a dcop client
    //app.dcopClient()->registerAs(app.name(), false);

    // see if we are starting with session management
    
    //if (app.isRestored())
    //    RESTORE(Klamav)
    //else
    //{
        // no session.. just start up normally
        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
        if (args->count() == 0)
        {
            new Klamav;
            //widget->show();
        }
        else
        {
            //int i = 0;
            //for (; i < args->count(); i++)
            //{
                new Klamav;
                //widget->show();
                //widget->load(args->url(i));
            //}
        }
        args->clear();
    //}
    return app.exec();
}
